OC.L10N.register(
    "core",
    {
    "Please select a file." : "Будь ласка, оберіть файл.",
    "File is too big" : "Файл занадто великий",
    "The selected file is not an image." : "Обраний файл не є зображенням.",
    "The selected file cannot be read." : "Неможливо прочитати обраний файл.",
    "Invalid file provided" : "Надано невірний файл",
    "No image or file provided" : "Зображення або файлу не надано",
    "Unknown filetype" : "Невідомий тип файлу",
    "Invalid image" : "Невірне зображення",
    "An error occurred. Please contact your admin." : "Виникла помилка. Будь ласка, зв'яжіться з вашим адміністратором.",
    "No temporary profile picture available, try again" : "Тимчасове зображення профілю недоступне, спробуйте ще раз",
    "No crop data provided" : "Не вказана інформація про кадрування",
    "No valid crop data provided" : "Не вказані коректні дані про кадрування",
    "Crop is not square" : "Кадр не є квадратом",
    "State token does not match" : "Токен стану не збігається",
    "Could not complete login" : "Не вдалося увійти",
    "Password reset is disabled" : "Заборонено скидання паролю",
    "Couldn't reset password because the token is invalid" : "Неможливо скинути пароль, бо маркер є недійсним",
    "Couldn't reset password because the token is expired" : "Неможливо скинути пароль, бо маркер застарів",
    "%s password reset" : "%s скидання паролю",
    "Password reset" : "Скидання паролю",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Щоб скинути Ваш пароль, натисніть кнопку нижче. Якщо ви не робили запиту на скдування паролю, можете проігнорувати цей лист.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Натисніть на посилання для скидання вашого паролю. Якщо ви не збираєтесь змінювати пароль - проігноруйте цей лист.",
    "Reset your password" : "Скинути пароль",
    "Preparing update" : "Підготовка до оновлення",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Просимо запустити процес оновлення з командного рядка, оскільки автоматичне оновлення вимкнено у файлі config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Перевірка таблиці %s",
    "Turned on maintenance mode" : "Увімкнено режим технічного обслуговування",
    "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
    "Maintenance mode is kept active" : "Режим обслуговування залишається активним",
    "Updating database schema" : "Оновлення схеми бази даних",
    "Updated database" : "Базу даних оновлено",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Перевіряю, чи схема бази даних може бути оновлена (це може зайняти багато часу, залежно від розмірів бази даних)",
    "Checked database schema update" : "Перевірено оновлення схеми бази даних",
    "Checking updates of apps" : "Перевірка оновлень додатків",
    "Checking for update of app \"%s\" in appstore" : "Перевірка оновлень для додатку \"%s\" в крамниці додатків",
    "Update app \"%s\" from appstore" : "Оновлення додатку \"1%s\" з магазину додатків",
    "Checked for update of app \"%s\" in appstore" : "Наявність оновлення додатку \"%s\" в магазині додатків провірено",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Перевіряю, чи схема бази даних для %s може бути оновлена (це може зайняти багато часу, залежно від розмірів бази даних)",
    "Checked database schema update for apps" : "Перевірено оновлення схеми бази даних для додатків",
    "Updated \"%1$s\" to %2$s" : "Оновлено з \"%1$s\" до %2$s",
    "Set log level to debug" : "Встановити рівень детальності журналу як налагодження",
    "Reset log level" : "Скинути налаштування детальності журналу",
    "Starting code integrity check" : "Початок перевірки цілісності коду",
    "Finished code integrity check" : "Завершено перевірку цілісності коду",
    "%s (incompatible)" : "%s (несумісне)",
    "Following apps have been disabled: %s" : "Наступні додатки були вимкнені: %s",
    "Already up to date" : "Вже актуально",
    "Very weak password" : "Дуже слабкий пароль",
    "Weak password" : "Слабкий пароль",
    "So-so password" : "Такий собі пароль",
    "Good password" : "Добрий пароль",
    "Strong password" : "Надійний пароль",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Ваш веб-сервер не налаштований як треба для синхронізації файлів, схоже інтерфейс WebDAV поламаний.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Ваш веб-сервер не налаштований як треба для вирішення \"{url}\". Додаткову інформація може знаходитись в нашій <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документації</a>.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP не налаштований правильно для отримання змінних системного оточення. Запит getenv(\"PATH\") повертає пусті результати.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Перевірте розділи <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документації по встановленню ↗</a> з замітками налаштування PHP на вашому сервері, особливо коли використовуєте php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Увімкнена конфігурація тільки для читання. Це запобігає встановленню деяких опцій через веб-інтерфейс. Крім того, для кожного оновлення файл повинен бути зроблений з доступом на запис.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Не вдалося виконати завдання cron за допомогою CLI. Виникла наступна технічна помилка:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "Останнє виконання фонового завдання тривало {relativeTime}. Схоже, щось пішло не так.",
    "Check the background job settings" : "Перевірте налаштування фонового завдання",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Не налаштована система кешування. Для покращення продуктивності, будь-ласка, налаштуйте memcache, якщо це можливо. Додаткову інформацію можна знайти в <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документації</a>.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Ви використовуєте PHP версії 5.6. Поточна основна версія Nextcloud остання, яка підтримуватиме PHP версію 5.6. Рекомендуємо оновити PHP до версії 7.0+ щоб мати змогу оновитись до Nextcloud 14.",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "Модуль PHP OPCache не завантажений. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Для кращої продуктивності рекомендується</a> завантажити його у свою установку PHP.",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "Модуль PHP OPcache налаштовано неправильно. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Для підвищення продуктивності рекомендується</a> використовувати наступні параметри у <code>php.ini</code>:",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Відсутній індекс \"{indexName}\" у таблиці \"{tableName}\".",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite в даний час використовується як база даних бекенда.  Для великих установок ми рекомендуємо перейти на інший тип серверу баз даних.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Це особливо рекомендується при використанні клієнтського ПК для синхронізації файлів.",
    "The PHP memory limit is below the recommended value of 512MB." : "Обсяг пам'яті PHP нижчий від рекомендованого значення 512 МБ.",
    "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
    "Non-existing tag #{tag}" : "Ця позначка відсутня #{tag}",
    "restricted" : "обмежений",
    "invisible" : "невидимий",
    "({scope})" : "({scope})",
    "Delete" : "Видалити",
    "Rename" : "Перейменувати",
    "Collaborative tags" : "Позначки для співпраці",
    "No tags found" : "Міток не знайдено",
    "unknown text" : "невідомий текст",
    "Hello world!" : "Привіт світ!",
    "sunny" : "сонячно",
    "Hello {name}, the weather is {weather}" : "Привіт {name}, погода {weather} ",
    "Hello {name}" : "Привіт {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Це ваші результати пошуку<script>alert(1)</script></strong>",
    "new" : "новий",
    "_download %n file_::_download %n files_" : ["завантаження %n файлу","завантаження %n файлів","завантаження %n файлів","завантаження %n файлів"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Відбувається оновлення. Не залишайте цю сторінку, це може перервати процес у деяких середовищах.",
    "Update to {version}" : "Оновлення до {version}",
    "An error occurred." : "Виникла помилка.",
    "Please reload the page." : "Будь ласка, перезавантажте сторінку.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Оновлення не вдалося. За інформацією <a href=\"{url}\">зверніться до повідомлення на форумі</a>, що описує цю проблему.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Оновлення не вдалося. Будь ласка, повідомте про це питання в <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">спільноту Nextcloud</a>.",
    "Continue to Nextcloud" : "Продовжити у Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Оновлення успішне. Перенаправлення до Nextcloud через %n секунду.","Оновлення успішне. Перенаправлення до Nextcloud через %n секунди.","Оновлення успішне. Перенаправлення до Nextcloud через %n секунд.","Оновлення успішне. Перенаправлення до Nextcloud через %n секунд."],
    "Searching other places" : "Йде пошук в інших місцях",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нічого не знайдено в інших каталогах за запитом {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} результат пошуку в інших теках","{count} результатів пошуку в інших теках","{count} результатів пошуку в інших теках","{count} результатів пошуку в інших теках"],
    "Server side authentication failed!" : "Невдала аутентифікація на стороні сервера!",
    "Please contact your administrator." : "Будь ласка, зверніться до вашого Адміністратора.",
    "An internal error occurred." : "Виникла внутрішня помилка.",
    "Please try again or contact your administrator." : "Будь ласка, спробуйте ще раз або зверніться до адміністратора.",
    "Username or email" : "Ім’я користувача або електронна пошта",
    "Password" : "Пароль",
    "Log in" : "Увійти",
    "Logging in …" : "Вхід...",
    "Wrong username or password." : "Неправильне ім’я користувача або пароль.",
    "User disabled" : "Користувач відключений",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ми виявили кілька недійсних спроб входу з вашого IP-адресу. Тому  наступну спробу входу можна буде здійснити через 30 секунд.",
    "Reset password" : "Скинути пароль",
    "Couldn't send reset email. Please contact your administrator." : "Не можу надіслати email для скидання. Будь ласка, зверніться до вашого адміністратора.",
    "Password can not be changed. Please contact your administrator." : "Пароль не може бути змінено. Будь ласка, зверніться до вашого адміністратора",
    "Back to login" : "Повернутися на сторінку входу",
    "New password" : "Новий пароль",
    "I know what I'm doing" : "Я знаю що роблю",
    "Cancel" : "Скасувати",
    "Forgot password?" : "Забули пароль?",
    "Settings" : "Налаштування",
    "Could not load your contacts" : "Неможливо завантажити ваші контакти",
    "Search contacts …" : "Пошук контактів...",
    "No contacts found" : "Контактів не знайдено",
    "Show all contacts …" : "Показати всі контакти ...",
    "Loading your contacts …" : "Завантаження ваших контактів ...",
    "Looking for {term} …" : "Шукаєте {term}",
    "No" : "Ні",
    "Yes" : "Так",
    "No files in here" : "Тут немає файлів",
    "New folder" : "Нова тека",
    "No more subfolders in here" : "Тут більше немає підкаталогів",
    "Name" : "Ім’я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "{newName} already exists" : "{newName} вже існує",
    "Choose" : "Обрати",
    "Copy" : "Копіювати",
    "Move" : "Перемістити",
    "Error loading file picker template: {error}" : "Помилка при завантаженні шаблону вибору: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Помилка при завантаженні шаблону повідомлення: {error}",
    "read-only" : "Тільки для читання",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файловий конфлікт","{count} файлових конфліктів","{count} файлових конфліктів","{count} файлових конфліктів"],
    "One file conflict" : "Один файловий конфлікт",
    "New Files" : "Нових Файлів",
    "Already existing files" : "Файли що вже існують",
    "Which files do you want to keep?" : "Які файли ви хочете залишити?",
    "If you select both versions, the copied file will have a number added to its name." : "При виборі обох версій, до назви копійованого файлу буде додана цифра",
    "Continue" : "Продовжити",
    "(all selected)" : "(все обрано)",
    "({count} selected)" : "({count} обраних)",
    "Error loading file exists template" : "Помилка при завантаженні шаблону існуючого файлу",
    "Pending" : "Очікування",
    "Copy to {folder}" : "копіювання до {folder}",
    "Move to {folder}" : "Переміщення до {folder}",
    "Saving..." : "Збереження...",
    "Authentication required" : "Необхідна автентифікація",
    "This action requires you to confirm your password" : "Ця дія потребує підтвердження вашого пароля",
    "Confirm" : "Підтвердити",
    "Failed to authenticate, try again" : "Помилка автентифікації, спробуйте ще раз",
    "seconds ago" : "секунди тому",
    "Connection to server lost" : "З'єднання з сервером втрачено",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблема під час завантаження сторінки, повторне завантаження за %n сек.","Проблема під час завантаження сторінки, повторне завантаження за %n сек.","Проблема під час завантаження сторінки, повторне завантаження за 5 сек.","Проблема під час завантаження сторінки, повторне завантаження за 5 сек."],
    "New in" : "Нові можливості",
    "View changelog" : "Подивитись зміни",
    "No action available" : "Немає доступних дій",
    "Error fetching contact actions" : "Неможливо отримати дії з контактами",
    "Personal" : "Особисте",
    "Users" : "Користувачі",
    "Apps" : "Додатки",
    "Admin" : "Адмін",
    "Help" : "Допомога",
    "Access forbidden" : "Доступ заборонено",
    "File not found" : "Файл не знайдено",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документ не знайдено на сервері. Може бути, доступ до нього був видалений, або минув термін дії доступу?",
    "Back to %s" : "Назад до %s",
    "Error" : "Помилка",
    "Internal Server Error" : "Внутрішня помилка серверу",
    "The server was unable to complete your request." : "Сервер не зміг обробити ваш запит.",
    "If this happens again, please send the technical details below to the server administrator." : "Якщо це станеться знову, надішліть технічні подробиці нижче адміністратору сервера.",
    "More details can be found in the server log." : "Більше деталей може бути в журналі серверу.",
    "Technical details" : "Технічні деталі",
    "Remote Address: %s" : "Віддалена Адреса: %s",
    "Request ID: %s" : "ID запиту: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Повідомлення: %s",
    "File: %s" : "Файл: %s",
    "Line: %s" : "Рядок: %s",
    "Trace" : "Трасування",
    "Security warning" : "Попередження безпеки",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог даних і ваші файли можливо доступні з інтернету, тому що  .htaccess файл не працює.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Для отримання інформації про те, як правильно налаштувати свій сервер, перегляньте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацію</a>.",
    "Create an <strong>admin account</strong>" : "Створити <strong>обліковий запис адміністратора</strong>",
    "Username" : "Ім'я користувача",
    "Storage & database" : "Сховище і база даних",
    "Data folder" : "Каталог даних",
    "Configure the database" : "Налаштування бази даних",
    "Only %s is available." : "Доступно тільки %s.",
    "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP для того, щоб обрати тип БД.",
    "For more details check out the documentation." : "За подробицями зверніться до документації.",
    "Database user" : "Користувач бази даних",
    "Database password" : "Пароль для бази даних",
    "Database name" : "Назва бази даних",
    "Database tablespace" : "Таблиця бази даних",
    "Database host" : "Хост бази даних",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Будь ласка, вкажіть номер порту поряд з ім'ям хоста (напр., localhost:5432).",
    "Performance warning" : "Попередження продуктивності",
    "Finish setup" : "Завершити встановлення",
    "Finishing …" : "Завершується ...",
    "Need help?" : "Потрібна допомога?",
    "See the documentation" : "Подивитись документацію",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ця програма вимагає увімкнений JavaScript для коректної роботи. Будь ласка, {linkstart} Увімкніть JavaScript {linkend}  та перезавантажте сторінку.",
    "Get your own free account" : "Отримати безкоштовний обліковий запис",
    "Skip to main content" : "Перейти до основного вмісту",
    "Skip to navigation of app" : "Перейти до навігації по додатку",
    "More apps" : "Більше додатків",
    "More" : "Додатково",
    "More apps menu" : "Меню з більшим числом застосунків",
    "Search" : "Пошук",
    "Reset search" : "Повторити пошук",
    "Contacts" : "Контакти",
    "Contacts menu" : "Меню контактів",
    "Settings menu" : "Меню налаштувань",
    "Confirm your password" : "Підтвердіть пароль",
    "Connect to your account" : "Підключитись до свого облікового запису",
    "Please log in before granting %1$s access to your %2$s account." : "Для надання %1$s доступу до облікового запису %2$s необхідно увійти в систему.",
    "App token" : "Токен додатку",
    "Grant access" : "Дозволити доступ",
    "Alternative log in using app token" : "Вхід за допомогою токену додатку",
    "Account access" : "Доступ до облікового запису",
    "You are about to grant %1$s access to your %2$s account." : "Ви збираєтесь надати %1$s доступ до свого облікового запису %2$s.",
    "Account connected" : "Обліковий запис під’єднано",
    "This share is password-protected" : "Доступ до цього ресурсу захищений паролем",
    "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
    "Two-factor authentication" : "Двофакторна аутентифікація",
    "Use backup code" : "Використати резервний код",
    "Setup two-factor authentication" : "Налаштувати двофакторну автентифікацію",
    "Access through untrusted domain" : "Доступ з не довіреного домену",
    "App update required" : "Додаток потребує оновлення",
    "%1$s will be updated to version %2$s" : "%1$s буде оновлено до версії%2$s",
    "These apps will be updated:" : "Ці додатки будуть оновлені:",
    "These incompatible apps will be disabled:" : "Ці несумісні додатки будуть вимкнені:",
    "The theme %s has been disabled." : "Тему %s було вимкнено.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продовженням переконайтеся, що ви зробили резервну копію бази даних, каталогу конфігурації та каталогу з даними.",
    "Start update" : "Почати оновлення",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Щоб уникнути затримок у великих встановленнях, ви можете виконати наступну команду в каталозі встановлення:",
    "Detailed logs" : "Деталізований журнал",
    "Update needed" : "Оновлення необхідно",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Будь ласка, скористайтеся оновленням з командного рядка, оскільки у вас є більш ніж 50 користувачів.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Щоб отримати допомогу, перегляньте  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацію</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, що, якщо я продовжую виконувати оновлення через веб-інтерфейс, існує ризик того, що запит завершиться по тайм-ауту, що може призвести до втрати даних, але я маю резервну копію та знаю, як відновити мій екземпляр у випадку невдачі.",
    "Upgrade via web on my own risk" : "Оновлення через веб-інтерфейс на свій страх і ризик",
    "Maintenance mode" : "Режим технічного обслуговування",
    "This %s instance is currently in maintenance mode, which may take a while." : "Цей сервер %s знаходиться в режимі технічного обслуговування, що може зайняти деякий час.",
    "This page will refresh itself when the instance is available again." : "Ця сторінка оновиться автоматично, коли сервер знову стане доступний.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора якщо це повідомлення не зникає або з'являється несподівано.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Не вдалося відправити скидання паролю, тому що немає адреси електронної пошти для цього користувача. Будь ласка, зверніться до адміністратора.",
    "Couldn't send reset email. Please make sure your username is correct." : "Не вдалося відправити скидання паролю. Будь ласка, переконайтеся, що ваше ім'я користувача є правильним.",
    "Dismiss" : "Припинити",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Посилання для скидання вашого паролю було надіслано на ваш email. Якщо ви не отримали його найближчим часом, перевірте теку зі спамом.<br>Якщо і там немає, спитайте вашого місцевого адміністратора.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваші файли зашифровані. Якщо ви не зробили ключ відновлення, після скидання паролю відновити ваші дані буде неможливо.<br /> Якщо ви не знаєте, що робити, будь ласка, зверніться до адміністратора перед продовженням.<br /> Ви дійсно хочете продовжити?",
    "Sending email …" : "Відправлення пошти ...",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "Встановлена версія {name} є меншою, ніж {version}, з причин стабільності та ефективності рекомендовано оновити версію {name}.",
    "Shared" : "Опубліковано",
    "Shared with" : "Спільний доступ з",
    "Shared by" : "Поділився",
    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
    "Choose a password for the public link or press the \"Enter\" key" : "Встановіть пароль на публічне посилання або натисніть на \"Enter\"",
    "Copied!" : "Скопійовано!",
    "Copy link" : "Скопіювати посилання",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "Unable to create a link share" : "Неможливо створити посилання на загальнодоступний ресурс",
    "Unable to toggle this option" : "Не вдається переключити цей параметр",
    "Resharing is not allowed" : "Пере-публікація не дозволяється",
    "Link" : "Посилання",
    "Hide download" : "Сховати завантаження",
    "Password protection enforced" : "Вимагати захист паролем",
    "Password protect" : "Захистити паролем",
    "Allow editing" : "Дозволити редагування",
    "Email link to person" : "Надіслати посилання електронною поштою",
    "Send" : "Надіслати",
    "Allow upload and editing" : "Дозволити завантаження та редагування",
    "Read only" : "Тільки для читання",
    "File drop (upload only)" : "Сховище (тільки завантажування)",
    "Expiration date enforced" : "Вимагати термін дії",
    "Set expiration date" : "Встановити термін дії",
    "Expiration" : "Закінчення",
    "Expiration date" : "Термін дії",
    "Note to recipient" : "Примітка для одержувача",
    "Unshare" : "Закрити доступ",
    "Delete share link" : "Видалити посилання для спільного використання",
    "Add another link" : "Додати інше посилання",
    "Password protection for links is mandatory" : "Захист паролем для посилань є обов'язковим",
    "Share to {name}" : "Поділитися з {name}",
    "Share link" : "Поділитись посиланням",
    "New share link" : "Нове посилання для спільного доступу",
    "Created on {time}" : "Створено о {time}",
    "Password protect by Talk" : "Захист пароля Talk",
    "Could not unshare" : "Неможливо припинити ділитися файлом",
    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
    "Shared with you and {circle} by {owner}" : "{owner} опублікував для вас, та для круга {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поділився з вами, а також чатом {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} поділився з вами у чаті",
    "Shared with you by {owner}" : "{owner} опублікував для Вас",
    "Choose a password for the mail share" : "Встановіть пароль на спільне посилання через електронну пошту",
    "group" : "група",
    "remote" : "віддалений",
    "remote group" : "віддалена група",
    "email" : "електронна пошта",
    "conversation" : "розмова",
    "shared by {sharer}" : "поділився {sharer}",
    "Can reshare" : "Можна ділитися з іншими",
    "Can edit" : "Можна редагувати",
    "Can create" : "Можна створити",
    "Can change" : "Можна змінювати",
    "Can delete" : "Можна видаляти",
    "Access control" : "Контроль доступу",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} ділиться через посилання",
    "Error while sharing" : "Помилка під час публікації",
    "Share details could not be loaded for this item." : "Неможливо отримати докладну інформацію щодо цього спільного ресурсу",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Як мінімум {count} символ потрібен для автозавершення","Як мінімум {count} символи потрібні для автозавершення","Як мінімум {count} символів потрібно для автозавершення","Як мінімум {count} символів потрібно для автозавершення"],
    "No users or groups found for {search}" : "Не знайдено груп або користувачів за пошуком {search}",
    "No users found for {search}" : "Не знайдено жодного користувача для {search}",
    "An error occurred. Please try again" : "Сталася помилка. Спробуйте ще раз",
    "Home" : "Домашній",
    "Work" : "Робочий",
    "Other" : "Інший",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Поділитися",
    "Name or email address..." : "Ім'я або адреса електронної пошти...",
    "Name or federated cloud ID..." : "Ім'я, або ID федеративної хмари...",
    "Name, federated cloud ID or email address..." : "Ім'я, ID федеративної хмари або адреса електронної пошти...",
    "Name..." : "Ім’я",
    "Error removing share" : "Помилка під час вилучення спільного",
    "SQLite will be used as database." : "В якості бази даних буде використана SQLite.",
    "For larger installations we recommend to choose a different database backend." : "Для великих установок ми радимо вибрати іншу базу даних.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Використання SQLite особливо не рекомендується при синхронізації файлів з використанням клієнта для ПК.",
    "Wrong password." : "Невірний пароль.",
    "New Password" : "Новий пароль",
    "Cancel log in" : "Скасувати вхід",
    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Посилання для скидання вашого паролю було надіслано на ваш email. Якщо ви не отримали його найближчим часом, перевірте теку зі спамом.<br>Якщо і там немає, спитайте вашого місцевого адміністратора.",
    "Search globally" : "Шукати всюди",
    "Your client should now be connected! You can close this window." : "Тепер ваш клієнт під’єднано. Ви можете закрити це вікно."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
